package WebService::Braintree::CreditCard::CountryOfIssuance;
$WebService::Braintree::CreditCard::CountryOfIssuance::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant Yes => "Yes";
use constant No => "No";
use constant Unknown => "Unknown";

1;
__END__
